# Stripe Python bindings

[![Build Status](https://travis-ci.org/allanlei/stripe-requests.png?branch=master)](https://travis-ci.org/allanlei/stripe-requests)

## Installation

You don't need this source code unless you want to modify the
package. If you just want to use the Stripe Python bindings, you
should run:

```python
pip install --upgrade stripe-requests
```

or

```python
easy_install --upgrade stripe-requests
```

See http://www.pip-installer.org/en/latest/index.html for instructions
on installing pip. If you are on a system with easy_install but not
pip, you can use easy_install instead. If you're not using virtualenv,
you may have to prefix those commands with +sudo+. You can learn more
about virtualenv at http://www.virtualenv.org/

To install from source, run:

```python
python setup.py install
```

## Documentation

Please see https://stripe-requests.readthedocs.org/ for the most up-to-date
documentation.